v0.1.1 (2019-12-20)
===================

- Remove man pages from source.
- Use explicit regex match for kiwi version.
- Handle multiple digit versions with kiwi version.

v0.1.0 (2019-11-20)
===================

- Allow expressive image conditions similar to package conditions.

v0.0.4 (2019-10-24)
===================

- Remove usr dir from spec.
- Account for content after checksum.

v0.0.3 (2019-07-10)
===================

- Release matches version.

v0.0.2 (2019-07-10)
===================

- No changes

v0.0.1 (2019-07-10)
===================

- Initial release.
